==> BigShot-fabric-1.21.6-13.0.1-sources.jar: com/blamejared/bigshot/BigShot.java <==
package com.blamejared.bigshot;

import com.blamejared.bigshot.mixin.WindowAccess;
import com.mojang.blaze3d.systems.RenderSystem;
import com.mojang.blaze3d.textures.GpuTexture;
import com.mojang.blaze3d.textures.TextureFormat;
import java.io.File;
import java.util.function.Consumer;
import net.minecraft.class_1041;
import net.minecraft.class_156;
import net.minecraft.class_2561;
import net.minecraft.class_276;
import net.minecraft.class_304;
import net.minecraft.class_310;
import net.minecraft.class_318;
import net.minecraft.class_3675;
import net.minecraft.class_9779;

public class BigShot {
    
    public static final class_304 KEY_2X_SCREENSHOT = class_156.method_656(() -> new class_304(
            "key.bigshot.take_screenshot_2x",
            class_3675.field_16237.method_1444(),
            "key.categories.misc"
    ));
    public static final class_304 KEY_3X_SCREENSHOT = class_156.method_656(() -> new class_304(
            "key.bigshot.take_screenshot_3x",
            class_3675.field_16237.method_1444(),
            "key.categories.misc"
    ));
    public static final class_304 KEY_4X_SCREENSHOT = class_156.method_656(() -> new class_304(
            "key.bigshot.take_screenshot_4x",
            class_3675.field_16237.method_1444(),
            "key.categories.misc"
    ));
    
    public static boolean TAKING_SCREENSHOT = false;
    
    public static void takeScreenshot(int scale, Consumer<class_2561> consumer) {
        
        class_310 mc = class_310.method_1551();
        takeScreenshot(mc.field_1697, scale, consumer);
    }
    
    public static void takeScreenshot(File folder, int scale, Consumer<class_2561> consumer) {
        
        class_310 mc = class_310.method_1551();
        class_1041 window = mc.method_22683();
        WindowAccess windowAccess = (WindowAccess) (Object) window;
        
        int oldWidth = window.method_4489();
        int oldHeight = window.method_4506();
        int newWidth = oldWidth * scale;
        int newHeight = oldHeight * scale;
        int oldGuiScale = window.method_4495();
        class_276 target = mc.method_1522();
        try {
            BigShot.TAKING_SCREENSHOT = true;
            window.method_35642(newWidth);
            window.method_35643(newHeight);
            target.method_1234(newWidth, newHeight);
            windowAccess.bigshot$onResize(0, newWidth, newHeight);
            window.method_15997((oldGuiScale * scale));
            mc.field_1773.method_3192(class_9779.field_51956, true);
            class_318.method_1659(folder, target, consumer);
        } catch(Exception var18) {
            consumer.accept(class_2561.method_43469("screenshot.failure", var18.getMessage()));
            var18.printStackTrace();
        } finally {
            BigShot.TAKING_SCREENSHOT = false;
            window.method_35642(oldWidth);
            window.method_35643(oldHeight);
            target.method_1234(oldWidth, oldHeight);
            windowAccess.bigshot$onResize(0, oldWidth, oldHeight);
            window.method_15997( oldGuiScale);
        }
        
    }
    
}

==> BigShot-fabric-1.21.9-16.0.1-sources.jar: com/blamejared/bigshot/BigShot.java <==
package com.blamejared.bigshot;

import com.blamejared.bigshot.mixin.WindowAccess;
import com.mojang.blaze3d.systems.RenderSystem;
import com.mojang.blaze3d.textures.GpuTexture;
import com.mojang.blaze3d.textures.TextureFormat;
import java.io.File;
import java.util.function.Consumer;
import net.minecraft.class_1041;
import net.minecraft.class_156;
import net.minecraft.class_2561;
import net.minecraft.class_276;
import net.minecraft.class_304;
import net.minecraft.class_310;
import net.minecraft.class_318;
import net.minecraft.class_3675;
import net.minecraft.class_9779;

public class BigShot {
    
    public static final class_304 KEY_2X_SCREENSHOT = class_156.method_656(() -> new class_304(
            "key.bigshot.take_screenshot_2x",
            class_3675.field_16237.method_1444(),
            class_304.class_11900.field_62556
    ));
    public static final class_304 KEY_3X_SCREENSHOT = class_156.method_656(() -> new class_304(
            "key.bigshot.take_screenshot_3x",
            class_3675.field_16237.method_1444(),
            class_304.class_11900.field_62556
    ));
    public static final class_304 KEY_4X_SCREENSHOT = class_156.method_656(() -> new class_304(
            "key.bigshot.take_screenshot_4x",
            class_3675.field_16237.method_1444(),
            class_304.class_11900.field_62556
    ));
    
    public static boolean TAKING_SCREENSHOT = false;
    
    public static void takeScreenshot(int scale, Consumer<class_2561> consumer) {
        
        class_310 mc = class_310.method_1551();
        takeScreenshot(mc.field_1697, scale, consumer);
    }
    
    public static void takeScreenshot(File folder, int scale, Consumer<class_2561> consumer) {
        
        class_310 mc = class_310.method_1551();
        class_1041 window = mc.method_22683();
        WindowAccess windowAccess = (WindowAccess) (Object) window;
        
        int oldWidth = window.method_4489();
        int oldHeight = window.method_4506();
        int newWidth = oldWidth * scale;
        int newHeight = oldHeight * scale;
        int oldGuiScale = window.method_4495();
        class_276 target = mc.method_1522();
        try {
            BigShot.TAKING_SCREENSHOT = true;
            window.method_35642(newWidth);
            window.method_35643(newHeight);
            target.method_1234(newWidth, newHeight);
            windowAccess.bigshot$onResize(0, newWidth, newHeight);
            window.method_15997((oldGuiScale * scale));
            mc.field_1773.method_3192(class_9779.field_51956, true);
            class_318.method_1659(folder, target, consumer);
        } catch(Exception var18) {
            consumer.accept(class_2561.method_43469("screenshot.failure", var18.getMessage()));
            var18.printStackTrace();
        } finally {
            BigShot.TAKING_SCREENSHOT = false;
            window.method_35642(oldWidth);
            window.method_35643(oldHeight);
            target.method_1234(oldWidth, oldHeight);
            windowAccess.bigshot$onResize(0, oldWidth, oldHeight);
            window.method_15997( oldGuiScale);
        }
        
    }
    
}
